@@ -9,7 +9,7 @@ use Error::Pure qw(err);
 use List::MoreUtils qw(none);
 use Scalar::Util qw(blessed);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -163,7 +163,7 @@ sub _tags_a {
 	);
 	if ($value->data_type eq 'plain') {
 		$self->{'tags'}->put(
-			['d', $value->data],
+			['d', @{$value->data}],
 		);
 	} elsif ($value->data_type eq 'tags') {
 		$self->{'tags'}->put($value->data);
@@ -229,7 +229,7 @@ Returns instance of object.
 
 =item * C<css>
 
-'CSS::Struct::Output' object for L<process_css> processing.
+'L<CSS::Struct::Output>' object for L</process_css> processing.
 
 Default value is undef.
 
@@ -247,7 +247,7 @@ Default value is 1.
 
 =item * C<tags>
 
-'Tags::Output' object.
+'L<Tags::Output>' object for L</process> processing.
 
 Default value is undef.
 
@@ -279,7 +279,7 @@ Returns undef.
 
  $obj->process;
 
-Process Tags structure for table view.
+Process L<Tags> structure for table view.
 
 Returns undef.
 
@@ -287,7 +287,7 @@ Returns undef.
 
  $obj->process_css;
 
-Process CSS::Struct structure for output.
+Process L<CSS::Struct> structure for output.
 
 Returns undef.
 
@@ -464,6 +464,97 @@ Returns undef.
  #   </table>
  # </body>
 
+=head1 EXAMPLE3
+
+=for comment filename=print_table_with_data_object.pl
+
+ use strict;
+ use warnings;
+
+ use CSS::Struct::Output::Indent;
+ use Data::HTML::A;
+ use Tags::HTML::Table::View;
+ use Tags::Output::Indent;
+
+ # Object.
+ my $css = CSS::Struct::Output::Indent->new;
+ my $tags = Tags::Output::Indent->new;
+ my $obj = Tags::HTML::Table::View->new(
+         'css' => $css,
+         'tags' => $tags,
+ );
+
+ # Table data.
+ my $prague = Data::HTML::A->new(
+         'data' => ['Prague'],
+         'url' => 'https://prague.cz',
+ );
+ my $table_data_ar = [
+         ['Country', 'Capital'],
+         ['Czech Republic', $prague],
+         ['Russia', 'Moscow'],
+ ];
+
+ # Process login button.
+ $obj->init($table_data_ar, 'No data.');
+ $obj->process_css;
+ $tags->put(['b', 'body']);
+ $obj->process;
+ $tags->put(['e', 'body']);
+ $obj->cleanup;
+
+ # Print out.
+ print "CSS\n";
+ print $css->flush."\n\n";
+ print "HTML\n";
+ print $tags->flush."\n";
+
+ # Output:
+ # CSS
+ # .table, .table td, .table th {
+ #         border: 1px solid #ddd;
+ #         text-align: left;
+ # }
+ # .table {
+ #         border-collapse: collapse;
+ #         width: 100%;
+ # }
+ # .table th, .table td {
+ #         padding: 15px;
+ # }
+ # 
+ # HTML
+ # <body>
+ #   <table class="table">
+ #     <tr>
+ #       <th>
+ #         Country
+ #       </th>
+ #       <th>
+ #         Capital
+ #       </th>
+ #     </tr>
+ #     <tr>
+ #       <td>
+ #         Czech Republic
+ #       </td>
+ #       <td>
+ #         <a href="https://prague.cz">
+ #           Prague
+ #         </a>
+ #       </td>
+ #     </tr>
+ #     <tr>
+ #       <td>
+ #         Russia
+ #       </td>
+ #       <td>
+ #         Moscow
+ #       </td>
+ #     </tr>
+ #   </table>
+ # </body>
+
 =head1 DEPENDENCIES
 
 L<Class::Utils>,
@@ -490,6 +581,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
